<?php
//En este modelo se encuentran todas las consultas realizadas en la tabla de serviciosfranquicias(Cosmetólogo)
class ServiciosGeneralesC_model extends CI_Model { 
   public function __construct() {
      parent::__construct();
   }
    //Función que hace la busqueda del servicio selecionado 
    public function buscarServicioGe($title){
    $datos['Zona1']=$this->serviciosGeneralesC_model->BuscarZona1();
    foreach ($datos['Zona1'] as $i => $Zona) 


      $datos['Modelo1']=$this->serviciosGeneralesC_model->BuscarModelo1();
      foreach ($datos['Modelo1'] as $a => $Modelo) 



    $this->db->join('tiposervicio','TipoServicio_IdTipoServicio=IdTipoServicio','inner');
    $this->db->join('categoria','Categoria_IdCategoria=IdCategoria','inner');
    $this->db->join('modelo','Modelo_IdModelo=IdModelo','inner');
    $this->db->join('zona','Zona_IdZona=IdZona','inner');
    $this->db->where('TipoServicio_IdTipoServicio','2');
    $this->db->where('NombreZona',$Zona);
    $this->db->where('Modelo_IdModelo',$Modelo);


    $this->db->like('NombreServicio',$title);
    $this->db->order_by('NombreServicio','ASC');
    
    return $this->db->get('serviciosgenerales')->result();
   }





  //Consulta que hace la busqueda del servicio seleccionado
   public function obtenerenlace ($id){
      $this->db->where('IdServiciosGenerales', $id);
     // $this->db->join('serviciosgenerales','ServiciosGenerales_IdServiciosGenerales=IdServiciosGenerales','inner');
      $query=$this->db->get('serviciosgenerales');
      if($query->num_rows()>0){
         return $query;

      }else{
         return FALSE;
      }

   }


   //Consulta que hace la busqueda de los modelos
   public function BuscarModelo(){
     $query = $this->db-> query('SELECT IdModelo,NombreModelo FROM modelo'); 
       if ($query->num_rows() > 0) { 
        foreach($query->result() as $row) 
         $arrDatos[htmlspecialchars($row->IdModelo, ENT_QUOTES)] = htmlspecialchars($row->NombreModelo, ENT_QUOTES); 
            $query->free_result(); 
            return $arrDatos; }
         }

    //Consulta que hace la busqueda de los tipos de servicio
    public function BuscarTipoS(){
     $query = $this->db-> query('SELECT IdTipoServicio,NombreTipoServicio FROM tiposervicio WHERE IdTipoServicio=1'); 
       if ($query->num_rows() > 0) { 
        foreach($query->result() as $row) 
         $arrDatos[htmlspecialchars($row->IdTipoServicio, ENT_QUOTES)] = htmlspecialchars($row->NombreTipoServicio, ENT_QUOTES); 
            $query->free_result(); 
            return $arrDatos; }
         }

     //Consulta que hace la busqueda de las categorias del servicio
    public function BuscarCategoria(){
     $query = $this->db-> query('SELECT IdCategoria,NombreCategoria FROM categoria'); 
       if ($query->num_rows() > 0) { 
        foreach($query->result() as $row) 
         $arrDatos[htmlspecialchars($row->IdCategoria, ENT_QUOTES)] = htmlspecialchars($row->NombreCategoria, ENT_QUOTES); 
            $query->free_result(); 
            return $arrDatos; }
         }

     //Consulta que hace la busqueda de las zonas registradas
    public function BuscarZona(){
     $query = $this->db-> query('SELECT IdZona,NombreZona FROM zona'); 
       if ($query->num_rows() > 0) { 
        foreach($query->result() as $row) 
         $arrDatos[htmlspecialchars($row->IdZona, ENT_QUOTES)] = htmlspecialchars($row->NombreZona, ENT_QUOTES); 
            $query->free_result(); 
            return $arrDatos; }
         } 

     //Consulta que hace la busqueda de la franquicia del usuario que fue logueado
     public function BuscarFranquicia(){
     $this->db->select('*');
     $this->db->from('usuarios');
     $this->db->join('franquicias','Franquicias_IdFranquicias=IdFranquicias','inner');
     $this->db->where('IdUsuarios',$this->session->userdata('IdUsuarios'));
     $query=$this->db->get();
       if ($query->num_rows() > 0) { 
        foreach($query->result() as $row) 
         $arrDatos[htmlspecialchars($row->IdFranquicias, ENT_QUOTES)] = htmlspecialchars($row->NombreFranquicia, ENT_QUOTES); 
            $query->free_result(); 
            return $arrDatos; }
         } 
     //Consulta que hace la busqueda de lo servicios generales registrados 
     public function BuscarServicio(){


      $datos['Zona1']=$this->serviciosGeneralesC_model->BuscarZona1();
      foreach ($datos['Zona1'] as $i => $Zona) 

          $datos['Modelo1']=$this->serviciosGeneralesC_model->BuscarModelo1();
      foreach ($datos['Modelo1'] as $a => $Modelo) 
        
     $this->db->select('*');
     $this->db->from('serviciosgenerales');
     $this->db->join('zona','Zona_IdZona=IdZona','inner');
     $this->db->join('modelo','Modelo_IdModelo=IdModelo','inner');
     $this->db->where('TipoServicio_IdTipoServicio', '2');
     $this->db->where('Modelo_IdModelo', $Modelo);
     $this->db->where('Zona_IdZona', $Zona);
    
     $query=$this->db->get();
       if ($query->num_rows() > 0) { 
        foreach($query->result() as $row) 
         $arrDatos[htmlspecialchars($row->IdServiciosGenerales, ENT_QUOTES)] = htmlspecialchars($row->NombreServicio, ENT_QUOTES); 
            $query->free_result(); 
            return $arrDatos; }
         }

    //Consulta que hace la busqueda de los datos del usuario que fue logueado
    public function BuscarUsuario(){
     $this->db->select('*');
     $this->db->from('usuarios');
     $this->db->where('IdUsuarios',$this->session->userdata('IdUsuarios'));
     $query=$this->db->get();
       if ($query->num_rows() > 0) { 
        foreach($query->result() as $row) 
         $arrDatos[htmlspecialchars($row->IdUsuarios, ENT_QUOTES)] = htmlspecialchars($row->NombreUsuario, ENT_QUOTES); 
            $query->free_result(); 
            return $arrDatos; }
         }

     public function BuscarZona1(){
     $this->db->select('*');
     $this->db->from('usuarios');
     $this->db->join('franquicias','Franquicias_IdFranquicias=IdFranquicias','inner');
     $this->db->join('zona','Zona_IdZona=IdZona','inner');
     $this->db->where('IdUsuarios',$this->session->userdata('IdUsuarios'));
     $query=$this->db->get();
       if ($query->num_rows() > 0) { 
        foreach($query->result() as $row) 
         $arrDatos[htmlspecialchars($row->IdZona, ENT_QUOTES)] = htmlspecialchars($row->NombreZona, ENT_QUOTES); 
            $query->free_result(); 
            return $arrDatos; }
         }

     public function BuscarModelo1(){
     $this->db->select('*');
     $this->db->from('usuarios');
     $this->db->join('franquicias','Franquicias_IdFranquicias=IdFranquicias','inner');
     $this->db->join('modelo','Modelo_IdModelo=IdModelo','inner');
     $this->db->where('IdUsuarios',$this->session->userdata('IdUsuarios'));
     $query=$this->db->get();
       if ($query->num_rows() > 0) { 
        foreach($query->result() as $row) 
         $arrDatos[htmlspecialchars($row->IdModelo, ENT_QUOTES)] = htmlspecialchars($row->IdModelo, ENT_QUOTES); 
            $query->free_result(); 
            return $arrDatos; }
         }
     
     
   
  
}
