<?php
ini_set('memory_limit', '-1');
//Este controlador manda a traer las acciones que ayudará a que el módulo realiza sus funciones(Franquiciatario)
class ServiciosPruebaF extends CI_Controller
{
	//Constructor que manda a traer las librerias de sesión y validación 
	//Manda a llamar el modelo 
	public function __construct()
	{
		parent::__construct();
		$this->load->model('servicios/Franquiciatario/serviciosPruebaF_model');
		$this->load->library(array('session','form_validation'));
	}


	//Función principal que valida que el usuario este logueado
	//Manda a traer la vista principal listaServiciosPrueba_view
	//Hace la consulta para mostrar todos los servicios prueba que esten registrados en la franquicia del usuario logueado
	public function index()
	{
		if($this->session->userdata('Rol_IdRol')==FALSE || 
			$this->session->userdata('Rol_IdRol') == '1'|| 
			$this->session->userdata('Rol_IdRol') == '3')
		{
			redirect(base_url().'acceso/acceso');
		} else {
//     	$data['Franquicias']=$this->serviciosPruebaF_model->BuscarFranquicia();
// 		foreach ($data['Franquicias'] as $i => $Franquicias) 
// 		$this->db->select('*');
// 		$this->db->join('franquicias','Franquicias_IdFranquicias=IdFranquicias','inner');
// 		$this->db->join('modelo','Modelo_IdModelo = IdModelo','inner');
// 		$this->db->join('serviciosgenerales','ServiciosGenerales_IdServiciosGenerales=IdServiciosGenerales','join');
// 		$this->db->join('tiposervicio','TipoServicio_IdTipoServicio=IdTipoServicio','join');	
// 		$this->db->where('TipoServicio_IdTipoServicio','3');
// 		$this->db->where('Franquicias_IdFranquicias',$i);
// 		$data['consulta']=$this->db->get('serviciosfranquicias')->result();
// //$dato['consulta']=$this->db->get('serviciosfranquicias')->result();


		//*******************servicios muestra*********************

	   	$datos['Franquicias']=$this->serviciosPruebaF_model->BuscarFranquicia();
		foreach ($datos['Franquicias'] as $i => $Franquicias)

	    $datos['Zona1']=$this->serviciosPruebaF_model->BuscarZona1();
        foreach ($datos['Zona1'] as $i => $Zona) 


      $datos['Modelo1']=$this->serviciosPruebaF_model->BuscarModelo1();
      foreach ($datos['Modelo1'] as $a => $Modelo) 



    $this->db->join('tiposervicio','TipoServicio_IdTipoServicio=IdTipoServicio','inner');
    $this->db->join('categoria','Categoria_IdCategoria=IdCategoria','inner');
    $this->db->join('modelo','Modelo_IdModelo=IdModelo','inner');
    $this->db->join('zona','Zona_IdZona=IdZona','inner');
    $this->db->where("(TipoServicio_IdTipoServicio = '3')");
    $this->db->where('NombreZona',$Zona);
    $this->db->where('Modelo_IdModelo',$Modelo);

    $datos['consulta']=$this->db->get('serviciosgenerales')->result();

		$this->load->view('layout/headerFran');
		$this->load->view('layout/menuFranquicia');
		$this->load->view('servicios/Franquiciatario/listaServiciosPrueba_view',$datos);
		$this->load->view('layout/footer');
		}
	}

	//Funcion que manda a traer la vista agregaServicioPruebaA_view para registrar el servicio prueba
	// public function agregar()
	// {
	// 	if($this->session->userdata('Rol_IdRol')==FALSE || 
	// 		$this->session->userdata('Rol_IdRol') == '1'|| 
	// 		$this->session->userdata('Rol_IdRol') == '3')
	// 	{
	// 		redirect(base_url().'acceso/acceso');
	// 	} else {
	// 	$this->load->view('layout/headerFran');
	// 	$this->load->view('layout/menuFranquicia');
	// 	$this->db->select('*');
	// 	$this->db->join('franquicias','Franquicias_IdFranquicias=IdFranquicias','inner');
	// 	$datos['consulta']=$this->db->get('usuarios')->result();
	// 	$this->db->select('*');
	// 	$datos['consulta']=$this->db->get('serviciosgenerales')->result();
	// 	$datos['ReModelo']=$this->serviciosPruebaF_model->BuscarModelo();
	// 	$datos['ReTipoS']=$this->serviciosPruebaF_model->BuscarTipoS();
	//     $datos['ReCategoria']=$this->serviciosPruebaF_model->BuscarCategoria();
	//     $datos['ReZona']=$this->serviciosPruebaF_model->BuscarZona();
	//     $datos['ReServicios']=$this->serviciosPruebaF_model->BuscarServicio();
	//     $datos['ReFranquicia']=$this->serviciosPruebaF_model->BuscarFranquicia();
	//     $datos['ReUsuario']=$this->serviciosPruebaF_model->BuscarUsuario();
	//     $datos['Zona1']=$this->serviciosPruebaF_model->BuscarZona1();
	//     foreach ($datos['Zona1'] as $i => $Zona) 
	// 	$this->load->view('servicios/Franquiciatario/agregaServicioPruebaF_view',$datos);
	// 	$this->load->view('layout/footer');
	// 	}
	// }

	//Funcion que muestra los datos del servicio seleccionado  
	public function serviciosPru()
	{
		if(isset($_GET['term'])){
			$result = $this->serviciosPruebaF_model->buscarServicioPrue($_GET['term']);
			if(count($result)>0){
				foreach ($result as $row) 
					$arr_result[] = array(
						'label' => $row->NombreServicio,
						'TipoServicio' => $row->NombreTipoServicio,
						'Modelo' => $row->NombreModelo,
						'Categoria' => $row->NombreCategoria,
						'SesionesServicio' => $row->SesionesServicio,
						'Precios' => $row->PreciosServicio,
						'Descripcion' => $row->DescripcionServicio,
						'Observaciones'	=> $row->ObservacionesServicio,
						'Zona'	=> $row->NombreZona,
						'Servicios'	=> $row->IdServiciosGenerales,
					);
						echo json_encode($arr_result);
					}
			}
	}

	// //Funcion que guarda los datos ingresados para poder registrarlos en la base de datos 
	// public function guardar()
	// {
	// 	$parametro['IdServiciosFranquicias']="FMAS".$this->input->post('Franquicia').$parametro['Servicios']=$this->input->post('Servicios');
	// 	$parametro['ServiciosGenerales_IdServiciosGenerales']=$this->input->post('Servicios');
	// 	$parametro['Franquicias_IdFranquicias']= $this->input->post('Franquicia');
	// 	$parametro['Usuarios_IdUsuarios'] = $this->input->post('Usuario');      
	// 	$this->serviciosPruebaF_model->GuardarServicioG($parametro);	
	// }

	//Función que manda a traer la vista buscarServiciosPrueba_view y hace la busqueda del servicio seleccionado 


	//Función que manda a traer la vista editarServiPrueba_view con los datos del servicio seleccionado
	public function VerInformacion()
	{
		if($this->session->userdata('Rol_IdRol')==FALSE || 
			$this->session->userdata('Rol_IdRol') == '1'|| 
			$this->session->userdata('Rol_IdRol') == '3')
		{
			redirect(base_url().'acceso/acceso');
		} else {
		$id= $this->uri->segment(5);
		$obtenerenlace = $this->serviciosPruebaF_model->obtenerenlace($id);
		if($obtenerenlace != FALSE){
			foreach ($obtenerenlace->result() as $fila) {
				$IdServiciosGenerales=$fila->IdServiciosGenerales;
				$Modelo_IdModelo=$fila->Modelo_IdModelo;
				$NombreServicio = $fila->NombreServicio;
				$TipoServicio_IdTipoServicio=$fila->TipoServicio_IdTipoServicio;
				$Categoria_IdCategoria=$fila->Categoria_IdCategoria;
				$SesionesServicio=$fila->SesionesServicio;
				$PreciosServicio=$fila->PreciosServicio;
				$DescripcionServicio=$fila->DescripcionServicio;
				$ObservacionesServicio=$fila->ObservacionesServicio;
				$Zona_IdZona=$fila->Zona_IdZona;
			}
			$data = array(
				'IdServiciosGenerales' => $IdServiciosGenerales,
				'Modelo_IdModelo' => $Modelo_IdModelo,
				'NombreServicio' => $NombreServicio,
				'TipoServicio_IdTipoServicio' => $TipoServicio_IdTipoServicio,
				'Categoria_IdCategoria' => $Categoria_IdCategoria,
				'SesionesServicio' => $SesionesServicio,	
				'PreciosServicio' => $PreciosServicio,
			    'DescripcionServicio' => $DescripcionServicio,
			    'ObservacionesServicio' => $ObservacionesServicio,
			    'Zona_IdZona' => $Zona_IdZona);
			}else{
				$data ='';
				return FALSE;
			
		}
		$data['ReModelo']=$this->serviciosPruebaF_model->BuscarModelo();
		$data['ReTipoS']=$this->serviciosPruebaF_model->BuscarTipoS();
	    $data['ReCategoria']=$this->serviciosPruebaF_model->BuscarCategoria();
	    $data['ReZona']=$this->serviciosPruebaF_model->BuscarZona();
	    $data['ReServicios']=$this->serviciosPruebaF_model->BuscarServicio();
	    $data['ReFranquicia']=$this->serviciosPruebaF_model->BuscarFranquicia();
		$this->load->view('layout/headerFran');
		$this->load->view('layout/menuFranquicia');
		$this->load->view('servicios/Franquiciatario/editarServiPrueba_view',$data);
		$this->load->view('layout/footer');
		}
	}


	//Función que guarda los datos actualizados del servicio
	public function editarenlace ()
	{
		$IdServiciosGenerales= $this -> uri->segment(5);
		$data=array(
			'Modelo_IdModelo' => $this ->input ->post('Modelo_IdModelo', true),
			'NombreServicio' => $this ->input ->post('NombreServicio', true),
			'TipoServicio_IdTipoServicio' => $this ->input->post('TipoServicio_IdTipoServicio', true),
			'Categoria_IdCategoria' => $this ->input->post('Categoria_IdCategoria', true),
			'Sesiones' => $this ->input->post('Sesiones', true),
			'PreciosServicios' => $this ->input ->post('PreciosServicios', true),
			'Descripcion' => $this ->input->post('Descripcion', true),
			'Observaciones' => $this ->input ->post('Observaciones', true),
			'Zona_IdZona' => $this ->input ->post('Zona_IdZona', true)
			);
		$this->serviciosPruebaF_model->editarenlace($IdServiciosGenerales, $data);
	}

  
	//Función que elimina al servicio
	public function eliminar() 
	{
		 $id= $this->uri->segment(5);
		 $this->serviciosPruebaF_model->eliminar($id);
		 redirect('servicios/Franquiciatario/ServiciosPruebaF');
	}



	//Función que muestra el tipo de modelo 
	public function MostrarModelo()
	{
		$options ="";
		if($this->input->post('IdModelo')){
			$IdTipo=$this->input->post('IdModelo');
			$Nombre=$this->serviciosPruebaF_model->BuscarModelo($IdTipo);
			foreach ($Nombre as $fila) {
				?>
                <option value="<?php echo $fila->id ?>"><?php echo $tipo_name ?></option>
                <?php
			}
		}

	}
	
	//Función que muestra el tipo de servicio
	public function MostrarTipoS()
	{
		$options ="";
		if($this->input->post('IdTipoServicio')){
			$IdTipo=$this->input->post('IdTipoServicio');
			$Nombre=$this->serviciosPruebaF_model->BuscarTipoS($IdTipo);
			foreach ($Nombre as $fila) {
				?>
                <option value="<?php echo $fila->id ?>"><?php echo $tipo_name ?></option>
                <?php
			}
		}

	}

	//Función que muestra el tipo de categoria
	public function MostrarCategoria()
	{
		$options ="";
		if($this->input->post('IdCategoria')){
			$IdCategoria=$this->input->post('IdCategoria');
			$NombreCategoria=$this->serviciosPruebaF_model->BuscarCategoria($IdCategoria);
			foreach ($Nombre as $fila) {
				?>
                <option value="<?php echo $fila->id ?>"><?php echo $categoria_name ?></option>
                <?php
			}
		}

	}

	//Función que muestra la zona
	public function MostrarZona()
	{
		$options ="";
		if($this->input->post('IdZona')){
			$IdZona=$this->input->post('IdZona');
			$Nombre=$this->serviciosPruebaF_model->BuscarZona($IdZona);
			foreach ($Nombre as $fila) {
				?>
                <option value="<?php echo $fila->id ?>"><?php echo $zona_name ?></option>
                <?php
			}
		}

	}

	//Función que muestra la franquicia del usuario logueado
	public function MostrarFranquicia()
	{
		$options ="";
		if($this->input->post('IdFranquicias')){
			$IdFranquicias=$this->input->post('IdFranquicias');
			$NombreFranquicia=$this->serviciosPruebaF_model->BuscarFranquicia($IdFranquicias);
			foreach ($Nombre as $fila) {
				?>
                <option value="<?php echo $fila->id ?>"><?php echo $franquicia_name ?></option>
                <?php
			}
		}
	}
	
}